package com.pennapps.stopwatch;

/*
	Copyright (C) Philip Peng
	
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

public class FormattedTime {

	private String time;
	private long startTime, pauseTime;
	private boolean started, running, paused;
	
	private long currentTime() {
		return System.currentTimeMillis();
	}
	
	public FormattedTime() {
		reset();
	}
	
	public String update() {
		if (running) {
			long elapsed, MM, SS, mm;
			elapsed = currentTime() - startTime;
			MM = (elapsed / (1000 * 60))% 60;
			SS = (elapsed / 1000) % 60;
			mm = (elapsed / 10) % 100;
			time = String.format("%d%d:%d%d:%d%d",
					MM / 10, MM % 10, SS / 10, SS % 10, mm / 10, mm % 10);
		}
		return time;
	}
	
	public String start() {
		if (!started) {
			startTime = currentTime();
		}
		if (paused && started) {
			startTime += (currentTime() - pauseTime);
			pauseTime = 0L;
		}
		update();
		started = true;
		running = true;
		paused = false;
		return time;
	}
	
	public String stop() {
		if (started && !paused) {
			pauseTime = currentTime();
		}
		update();
		paused = true;
		running = false;
		return time;
	}
	
	public String reset() {
		started = false;
		running = false;
		paused = false;
		startTime = currentTime();
		pauseTime = 0L;
		time = "00:00:00";
		return time;
	}
}
